@@ -22,20 +22,18 @@ from google.api_core import gapic_v1, operations_v1
 from google.api_core import retry as retries
 import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.cloud.location import locations_pb2  # type: ignore
+from google.iam.v1 import iam_policy_pb2  # type: ignore
+from google.iam.v1 import policy_pb2  # type: ignore
 from google.longrunning import operations_pb2  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
 
+from google.cloud.vmmigration_v1 import gapic_version as package_version
 from google.cloud.vmmigration_v1.types import vmmigration
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-vm-migration",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 class VmMigrationTransport(abc.ABC):
@@ -49,7 +47,7 @@ class VmMigrationTransport(abc.ABC):
         self,
         *,
         host: str = DEFAULT_HOST,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -348,6 +346,16 @@ class VmMigrationTransport(abc.ABC):
                 default_timeout=None,
                 client_info=client_info,
             ),
+            self.list_replication_cycles: gapic_v1.method.wrap_method(
+                self.list_replication_cycles,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.get_replication_cycle: gapic_v1.method.wrap_method(
+                self.get_replication_cycle,
+                default_timeout=None,
+                client_info=client_info,
+            ),
         }
 
     def close(self):
@@ -787,6 +795,81 @@ class VmMigrationTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def list_replication_cycles(
+        self,
+    ) -> Callable[
+        [vmmigration.ListReplicationCyclesRequest],
+        Union[
+            vmmigration.ListReplicationCyclesResponse,
+            Awaitable[vmmigration.ListReplicationCyclesResponse],
+        ],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def get_replication_cycle(
+        self,
+    ) -> Callable[
+        [vmmigration.GetReplicationCycleRequest],
+        Union[vmmigration.ReplicationCycle, Awaitable[vmmigration.ReplicationCycle]],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def list_operations(
+        self,
+    ) -> Callable[
+        [operations_pb2.ListOperationsRequest],
+        Union[
+            operations_pb2.ListOperationsResponse,
+            Awaitable[operations_pb2.ListOperationsResponse],
+        ],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def get_operation(
+        self,
+    ) -> Callable[
+        [operations_pb2.GetOperationRequest],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def cancel_operation(
+        self,
+    ) -> Callable[[operations_pb2.CancelOperationRequest], None,]:
+        raise NotImplementedError()
+
+    @property
+    def delete_operation(
+        self,
+    ) -> Callable[[operations_pb2.DeleteOperationRequest], None,]:
+        raise NotImplementedError()
+
+    @property
+    def get_location(
+        self,
+    ) -> Callable[
+        [locations_pb2.GetLocationRequest],
+        Union[locations_pb2.Location, Awaitable[locations_pb2.Location]],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def list_locations(
+        self,
+    ) -> Callable[
+        [locations_pb2.ListLocationsRequest],
+        Union[
+            locations_pb2.ListLocationsResponse,
+            Awaitable[locations_pb2.ListLocationsResponse],
+        ],
+    ]:
+        raise NotImplementedError()
+
     @property
     def kind(self) -> str:
         raise NotImplementedError()
